unit Filtapi;

// Header for the 32 bit filter apis
// you find all the filters installed in:
// HKEY_LOCAL_MACHINE/Software/Microsoft/Shared Tools/Graphics Filters !!!

// This is a translation from the FILTAPI.h provided by Thomas W. Lipp
// Note I removed all the Win16 stuff and the MACPPC stuff!!

interface

uses Windows, Graphics;

const
  MaxFilePathLength = 260;
  cchMaxGrExt = 4;

  grtEMF = $01;
  grtWMF = $02;
  grtPNG = $03;
  grtPICT = $04;
  grtJFIF = $05;

  grfImport = $8;
  grfExport = $10;

  // error codes:
  IE_NO_ERROR = 0;
  IE_INTERNAL_ERROR = -1;

  IE_BASE = $14B4;
  IE_NOT_MY_FILE = IE_BASE + 1;
  IE_TOO_BIG = IE_BASE + 2;
  IE_DUMB_BITMAP = IE_BASE + 3;
  IE_BAD_VCHAR = IE_BASE + 4;
  IE_BAD_TOKEN = IE_BASE + 5;
  IE_NO_VERIFY = IE_BASE + 6;
  IE_UNKNOWN_TYPE = IE_BASE + 7;
  IE_NOT_WP_FILE = IE_BASE + 8;
  IE_BAD_FILE_DATA = IE_BASE + 9;
  IE_IMPORT_ABORT = IE_BASE + $A;
  IE_MEM_FULL = IE_BASE + $B;
  IE_MSNG_FONTS = IE_BASE + $C;
  IE_META_TOO_BIG = IE_BASE + $D;
  IE_MEM_FAIL = IE_BASE + $E;

  IE_NO_FILTER = IE_BASE + $12;

  IE_UNSUPP_COMPR = IE_BASE + $29;
  IE_UNSUPP_VERSION = IE_BASE + $2A;
  IE_UNSUPP_COLOR = IE_BASE + $2B;

  IE_ERROR_NOMSG = IE_BASE + $37;
  IE_FILE_NOT_FOUND = IE_BASE + $3C;
  IE_BUG = IE_BASE + $51;
  IE_BAD_METAFILE = IE_BASE + $53;
  IE_BAD_METAFILE2 = $CCCC;

  IE_BAD_PARAM = IE_BASE + $100;
  IE_UNSUPP_FORMAT = IE_BASE + $101;
  FA_DISK_ERROR = 7150;


  // names of common registry/SetFilterPref options
  FiltOptProgressDialog = 'ShowProgressDialog';        // is a string in registry (yes, no)
  FiltOptQuality = 'Quality';                          // DWORD in registry (0..100)
  FiltOptBackgroundTransparent = 'SetMetafileBackgroundTransparent'; // String: (yes, no)

  // common Values
  strYes = 'Yes';
  strNo = 'No';


type
  FILEEXTENSION = packed record
    case Boolean of
      True: (rgchExt : Array[0..cchMaxGrExt-1] of char);
      False: (hfEmbed : THandle);
  end;

  FILESPEC = record
    wFlags : Word;
    fxExtension : FILEEXTENSION;
    uUnused : Word;
    strName : Array[0..MaxFilePathLength-1] of char;
    dcbFile : ULONG;

    // end version 2 fields

    dcbFileHigh : ULONG;
  end;
  TFileSpec = FILESPEC;
  PFileSpec = ^FILESPEC;

  // Version 2 support:
  GRPI = record
    hmf : THandle;    // metafile Handle
    bbox : TRect;     // tightly bounds the image (in metafile units)
    inch : WORD;      // metafile units per inch
  end;
  PGRPI = ^GRPI;


  // Version 3 support:
  V3HandleData = packed record
    case integer of
      0: (hmf : THandle);        // Handles and pointers to various Pics
      1: (hemf : THandle);
      2: (hpng : THandle);
      3: (pPng : Pointer);
      4: (hPict : THandle );
      5: (pPict : Pointer);
      6: (hJpeg : THandle );
      7: (pJpeg : Pointer );
  end;

  GRPIX = record
    cbGrpix : Word;           // size of this structure
    grt : Byte;               // Graphic type
    cbData : ULONG;           // number of bytes in the graphic
    fPointer : integer;       // indicates wheather the Pointer or the
                              // handle is used in data
    data : V3HandleData;      // data, handle or pointer

    bbox : TRect;             // tightly bounds the image (in metafile units)
    inch : ULONG;             // metafile units per inch
  end;
  PGRPIX = ^GRPIX;
  TGRPIX = GRPIX;


  // Declarations of the used functions:
  
  // Version 3 only:
  PercentComplete = function (lPct : Longint; pvData : Pointer ) : boolean;

  // all versions:
  GetFilerInfo = function (wVersion : Short; pIni : PChar;
                           phPrefMem : PHandle; lFlags : ULONG ): integer; stdcall;
  GetFilterPref = procedure( hInst : THandle; hWnd : THandle; hPrefMem : THandle;
                             wFlags : WORD ); stdcall;
  // Note for Version 3 handling: cast pgrpix := PGRPIX( pgrpi ); !!
  ExportGr = function ( pFileSpecifica : PFileSpec; pgrpi : PGRPI;
                        hPrefMem : THandle ) : integer; stdcall;
  ExportEmbeddedGr = function ( pFileSpecifica : PFileSpec;
                                pgrpi : PGRPI; hPrefMem : THandle; pdwSize : PULONG ) :integer;
                                stdcall;
  ImportGr = function ( hdcPrint : HDC; pFileSpecifica : PFileSpec;
                        pgrpi : PGRPI; hPrefMem : THandle ) : integer; stdcall;

  ImportEmbeddedGr = function (hdcPrint : HDC; pFileSpecifica : PFileSpec;
                        pgrpi : PGRPI; hPrefMem : THandle; ulSize : ULONG;
                        szMetafileName : PChar ) : integer; stdcall;
  RegisterPercentCallback = function (hPrefMem : THandle; pctComplete : PercentComplete;
                                      pvData : Pointer ) : integer; stdcall;
  SetFilterPref = function ( hPrefMem : THandle; szOption : PChar; pvValue : Pointer;
                             dwSize : ULONG; dwType : ULONG ) : integer; stdcall;


function GrfSupportFromGrt( grt : ULONG ) : ULONG;
function grfSupportEMF : ULONG;
function grfSupportWMF : ULONG;
function grfSupportPNG : ULONG;
function grfSupportPICT : ULONG;
function grfSupportJFIF : ULONG;

implementation

function GrfSupportFromGrt( grt : ULONG ) : ULONG;
begin
  Result := (1 shl ((grt) + 15));
end;

function grfSupportEMF : ULONG;
begin
  Result := GrfSupportFromGrt( grtEMF );
end;

function grfSupportWMF : ULONG;
begin
  Result := GrfSupportFromGrt( grtWMF );
end;

function grfSupportPNG : ULONG;
begin
  Result := GrfSupportFromGrt( grtPNG );
end;

function grfSupportPICT : ULONG;
begin
  Result := GrfSupportFromGrt( grtPICT );
end;

function grfSupportJFIF : ULONG;
begin
  Result := GrfSupportFromGrt( grtJFIF );
end;

end.
